@@ -364,8 +364,9 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	{
 		gtk_widget_show (error_widget);
 
-		gtk_box_pack_start_defaults (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
-					     error_widget);
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+		                    error_widget,
+		                    TRUE, TRUE, 0);
 		gtk_container_set_border_width (GTK_CONTAINER (error_widget),
 						5);
 
@@ -374,7 +375,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 		return;
 	}
 
-	dlg->priv->search_entry = gedit_history_entry_new ("gedit2_search_for_entry",
+	dlg->priv->search_entry = gedit_history_entry_new ("search-for-entry",
 							   TRUE);
 	gtk_widget_set_size_request (dlg->priv->search_entry, 300, -1);
 	gedit_history_entry_set_escape_func
@@ -390,7 +391,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 				   dlg->priv->search_entry,
 				   1, 2, 0, 1);
 
-	dlg->priv->replace_entry = gedit_history_entry_new ("gedit2_replace_with_entry",
+	dlg->priv->replace_entry = gedit_history_entry_new ("replace-with-entry",
 							    TRUE);
 	gedit_history_entry_set_escape_func
 			(GEDIT_HISTORY_ENTRY (dlg->priv->replace_entry),
@@ -631,3 +632,5 @@ gedit_search_dialog_get_wrap_around (GeditSearchDialog *dialog)
 
 	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->wrap_around_checkbutton));
 }
+
+/* ex:ts=8:noet: */
