@@ -49,10 +49,6 @@
 #include "gedit-marshal.h"
 #include "gedit-window.h"
 
-#ifdef BUILD_SPINNER
-#include "gedit-spinner.h"
-#endif
-
 #include "gseal-gtk-compat.h"
 
 #define AFTER_ALL_TABS -1
@@ -75,10 +71,8 @@ struct _GeditNotebookPrivate
 
 G_DEFINE_TYPE(GeditNotebook, gedit_notebook, GTK_TYPE_NOTEBOOK)
 
-static void gedit_notebook_finalize (GObject *object);
-
-static gboolean gedit_notebook_change_current_page (GtkNotebook *notebook,
-						    gint         offset);
+static gboolean gedit_notebook_change_current_page (GtkNotebook   *notebook,
+						    gint           offset);
 
 static void move_current_tab_to_another_notebook  (GeditNotebook  *src,
 						   GeditNotebook  *dest,
@@ -91,8 +85,6 @@ static GdkCursor *cursor = NULL;
 /* Signals */
 enum
 {
-	TAB_ADDED,
-	TAB_REMOVED,
 	TABS_REORDERED,
 	TAB_DETACHED,
 	TAB_CLOSE_REQUEST,
@@ -102,61 +94,42 @@ enum
 static guint signals[LAST_SIGNAL] = { 0 };
 
 static void
-gedit_notebook_destroy (GtkObject *object)
+gedit_notebook_finalize (GObject *object)
 {
 	GeditNotebook *notebook = GEDIT_NOTEBOOK (object);
 
-	if (!notebook->priv->destroy_has_run)
-	{
-		GList *children, *l;
+	g_list_free (notebook->priv->focused_pages);
 
-		children = gtk_container_get_children (GTK_CONTAINER (notebook));
+	G_OBJECT_CLASS (gedit_notebook_parent_class)->finalize (object);
+}
 
-		for (l = children; l != NULL; l = g_list_next (l))
-		{
-			gedit_notebook_remove_tab (notebook,
-						   GEDIT_TAB (l->data));
-		}
+static void
+gedit_notebook_grab_focus (GtkWidget *widget)
+{
+	GtkNotebook *nb = GTK_NOTEBOOK (widget);
+	GtkWidget *tab;
+	gint current_page;
 
-		g_list_free (children);
-		notebook->priv->destroy_has_run = TRUE;
-	}
+	GTK_WIDGET_CLASS (gedit_notebook_parent_class)->grab_focus (widget);
 
-	GTK_OBJECT_CLASS (gedit_notebook_parent_class)->destroy (object);
+	current_page = gtk_notebook_get_current_page (nb);
+	tab = gtk_notebook_get_nth_page (nb, current_page);
+
+	gtk_widget_grab_focus (tab);
 }
 
 static void
 gedit_notebook_class_init (GeditNotebookClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
+	GtkWidgetClass *gtkwidget_class = GTK_WIDGET_CLASS (klass);
 	GtkNotebookClass *notebook_class = GTK_NOTEBOOK_CLASS (klass);
 
 	object_class->finalize = gedit_notebook_finalize;
-	gtkobject_class->destroy = gedit_notebook_destroy;
+	gtkwidget_class->grab_focus = gedit_notebook_grab_focus;
 	
 	notebook_class->change_current_page = gedit_notebook_change_current_page;
 
-	signals[TAB_ADDED] =
-		g_signal_new ("tab_added",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GeditNotebookClass, tab_added),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
-			      G_TYPE_NONE,
-			      1,
-			      GEDIT_TYPE_TAB);
-	signals[TAB_REMOVED] =
-		g_signal_new ("tab_removed",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GeditNotebookClass, tab_removed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
-			      G_TYPE_NONE,
-			      1,
-			      GEDIT_TYPE_TAB);
 	signals[TAB_DETACHED] =
 		g_signal_new ("tab_detached",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -187,11 +160,12 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 			      1,
 			      GEDIT_TYPE_TAB);
 
-	g_type_class_add_private (object_class, sizeof(GeditNotebookPrivate));
+	g_type_class_add_private (object_class, sizeof (GeditNotebookPrivate));
 }
 
 static GeditNotebook *
-find_notebook_at_pointer (gint abs_x, gint abs_y)
+find_notebook_at_pointer (gint abs_x,
+			  gint abs_y)
 {
 	GdkWindow *win_at_pointer;
 	GdkWindow *toplevel_win;
@@ -663,7 +637,6 @@ gedit_notebook_switch_page_cb (GtkNotebook     *notebook,
 {
 	GeditNotebook *nb = GEDIT_NOTEBOOK (notebook);
 	GtkWidget *child;
-	GeditView *view;
 
 	child = gtk_notebook_get_nth_page (notebook, page_num);
 
@@ -678,9 +651,8 @@ gedit_notebook_switch_page_cb (GtkNotebook     *notebook,
 	nb->priv->focused_pages = g_list_append (nb->priv->focused_pages,
 						 child);
 
-	/* give focus to the view */
-	view = gedit_tab_get_view (GEDIT_TAB (child));
-	gtk_widget_grab_focus (GTK_WIDGET (view));
+	/* give focus to the tab */
+	gtk_widget_grab_focus (child);
 }
 
 /*
@@ -734,16 +706,6 @@ gedit_notebook_init (GeditNotebook *notebook)
                                 NULL);
 }
 
-static void
-gedit_notebook_finalize (GObject *object)
-{
-	GeditNotebook *notebook = GEDIT_NOTEBOOK (object);
-
-	g_list_free (notebook->priv->focused_pages);
-
-	G_OBJECT_CLASS (gedit_notebook_parent_class)->finalize (object);
-}
-
 /*
  * We need to override this because when we don't show the tabs, like in
  * fullscreen we need to have wrap around too
@@ -885,23 +847,18 @@ gedit_notebook_add_tab (GeditNotebook *nb,
 				  position);
 	update_tabs_visibility (nb, TRUE);
 
-	g_signal_emit (G_OBJECT (nb), signals[TAB_ADDED], 0, tab);
-
 	/* The signal handler may have reordered the tabs */
 	position = gtk_notebook_page_num (GTK_NOTEBOOK (nb), 
 					  GTK_WIDGET (tab));
 
 	if (jump_to)
 	{
-		GeditView *view;
-		
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (nb), position);
 		g_object_set_data (G_OBJECT (tab), 
 				   "jump_to",
 				   GINT_TO_POINTER (jump_to));
-		view = gedit_tab_get_view (tab);
 		
-		gtk_widget_grab_focus (GTK_WIDGET (view));
+		gtk_widget_grab_focus (GTK_WIDGET (tab));
 	}
 }
 
@@ -942,18 +899,9 @@ remove_tab (GeditTab      *tab,
 
 	position = gtk_notebook_page_num (GTK_NOTEBOOK (nb), GTK_WIDGET (tab));
 
-	/* we ref the tab so that it's still alive while the tabs_removed
-	 * signal is processed.
-	 */
-	g_object_ref (tab);
-
 	remove_tab_label (nb, tab);
 	gtk_notebook_remove_page (GTK_NOTEBOOK (nb), position);
 	update_tabs_visibility (nb, FALSE);
-
-	g_signal_emit (G_OBJECT (nb), signals[TAB_REMOVED], 0, tab);
-
-	g_object_unref (tab);
 }
 
 /**
