@@ -43,10 +43,11 @@
 
 #include "gedit-view.h"
 #include "gedit-debug.h"
-#include "gedit-prefs-manager.h"
-#include "gedit-prefs-manager-app.h"
 #include "gedit-marshal.h"
 #include "gedit-utils.h"
+#include "gseal-gtk-compat.h"
+#include "gedit-settings.h"
+#include "gedit-app.h"
 
 
 #define GEDIT_VIEW_SCROLL_MARGIN 0.02
@@ -69,6 +70,8 @@ enum
 
 struct _GeditViewPrivate
 {
+	GSettings   *editor_settings;
+
 	SearchMode   search_mode;
 	
 	GtkTextIter  start_search_iter;
@@ -139,9 +142,9 @@ static void 	search_highlight_updated_cb	(GeditDocument    *doc,
 						 GtkTextIter      *end,
 						 GeditView        *view);
 
-static void	gedit_view_delete_from_cursor 	(GtkTextView     *text_view,
-						 GtkDeleteType    type,
-						 gint             count);
+static void	gedit_view_delete_from_cursor 	(GtkTextView      *text_view,
+						 GtkDeleteType     type,
+						 gint              count);
 
 G_DEFINE_TYPE(GeditView, gedit_view, GTK_TYPE_SOURCE_VIEW)
 
@@ -334,21 +337,40 @@ on_notify_buffer_cb (GeditView  *view,
 static void 
 gedit_view_init (GeditView *view)
 {
+	GSettings *gs;
 	GtkTargetList *tl;
+	gboolean use_default_font;
+	gboolean display_line_numbers;
+	gboolean auto_indent;
+	gboolean insert_spaces;
+	gboolean display_right_margin;
+	gboolean hl_current_line;
+	guint tabs_size;
+	guint right_margin_position;
+	GtkWrapMode wrap_mode;
+	GtkSourceSmartHomeEndType smart_home_end;
 	
 	gedit_debug (DEBUG_VIEW);
 	
 	view->priv = GEDIT_VIEW_GET_PRIVATE (view);
 
+	gs = _gedit_app_get_settings (gedit_app_get_default ());
+	view->priv->editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
+
+	/* Get setting values */
+	use_default_font = g_settings_get_boolean (view->priv->editor_settings,
+						   GEDIT_SETTINGS_USE_DEFAULT_FONT);
+
 	/*
 	 *  Set tab, fonts, wrap mode, colors, etc. according
 	 *  to preferences 
 	 */
-	if (!gedit_prefs_manager_get_use_default_font ())
+	if (!use_default_font)
 	{
 		gchar *editor_font;
 
-		editor_font = gedit_prefs_manager_get_editor_font ();
+		editor_font = g_settings_get_string (view->priv->editor_settings,
+						     GEDIT_SETTINGS_EDITOR_FONT);
 
 		gedit_view_set_font (view, FALSE, editor_font);
 
@@ -358,17 +380,37 @@ gedit_view_init (GeditView *view)
 	{
 		gedit_view_set_font (view, TRUE, NULL);
 	}
+ 
+	display_line_numbers = g_settings_get_boolean (view->priv->editor_settings,
+						       GEDIT_SETTINGS_DISPLAY_LINE_NUMBERS);
+	auto_indent = g_settings_get_boolean (view->priv->editor_settings,
+					      GEDIT_SETTINGS_AUTO_INDENT);
+	g_settings_get (view->priv->editor_settings, GEDIT_SETTINGS_TABS_SIZE,
+			"u", &tabs_size);
+	insert_spaces = g_settings_get_boolean (view->priv->editor_settings,
+						GEDIT_SETTINGS_INSERT_SPACES);
+	display_right_margin = g_settings_get_boolean (view->priv->editor_settings,
+						       GEDIT_SETTINGS_DISPLAY_RIGHT_MARGIN);
+	g_settings_get (view->priv->editor_settings, GEDIT_SETTINGS_RIGHT_MARGIN_POSITION,
+			"u", &right_margin_position);
+	hl_current_line = g_settings_get_boolean (view->priv->editor_settings,
+						  GEDIT_SETTINGS_HIGHLIGHT_CURRENT_LINE);
+
+	wrap_mode = gedit_settings_get_wrap_mode (view->priv->editor_settings,
+						  GEDIT_SETTINGS_WRAP_MODE);
+	
+	smart_home_end = gedit_settings_get_smart_home_end (GEDIT_SETTINGS (gs));
 
 	g_object_set (G_OBJECT (view), 
-		      "wrap_mode", gedit_prefs_manager_get_wrap_mode (),
-		      "show_line_numbers", gedit_prefs_manager_get_display_line_numbers (),
-		      "auto_indent", gedit_prefs_manager_get_auto_indent (),
-		      "tab_width", gedit_prefs_manager_get_tabs_size (),
-		      "insert_spaces_instead_of_tabs", gedit_prefs_manager_get_insert_spaces (),
-		      "show_right_margin", gedit_prefs_manager_get_display_right_margin (), 
-		      "right_margin_position", gedit_prefs_manager_get_right_margin_position (),
-		      "highlight_current_line", gedit_prefs_manager_get_highlight_current_line (),
-		      "smart_home_end", gedit_prefs_manager_get_smart_home_end (),
+		      "wrap_mode", wrap_mode,
+		      "show_line_numbers", display_line_numbers,
+		      "auto_indent", auto_indent,
+		      "tab_width", tabs_size,
+		      "insert_spaces_instead_of_tabs", insert_spaces,
+		      "show_right_margin", display_right_margin,
+		      "right_margin_position", right_margin_position,
+		      "highlight_current_line", hl_current_line,
+		      "smart_home_end", smart_home_end,
 		      "indent_on_tab", TRUE,
 		      NULL);
 
@@ -414,6 +456,12 @@ gedit_view_destroy (GtkObject *object)
 	current_buffer_removed (view);
 	g_signal_handlers_disconnect_by_func (view, on_notify_buffer_cb, NULL);
 	
+	if (view->priv->editor_settings != NULL)
+	{
+		g_object_unref (view->priv->editor_settings);
+		view->priv->editor_settings = NULL;
+	}
+	
 	(* GTK_OBJECT_CLASS (gedit_view_parent_class)->destroy) (object);
 }
 
@@ -660,9 +708,12 @@ gedit_view_set_font (GeditView   *view,
 
 	if (def)
 	{
+		GSettings *settings;
 		gchar *font;
 
-		font = gedit_prefs_manager_get_system_font ();
+		settings = _gedit_app_get_settings (gedit_app_get_default ());
+		font = gedit_settings_get_system_font (GEDIT_SETTINGS (settings));
+		
 		font_desc = pango_font_description_from_string (font);
 		g_free (font);
 	}
@@ -677,7 +728,7 @@ gedit_view_set_font (GeditView   *view,
 
 	gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
 
-	pango_font_description_free (font_desc);		
+	pango_font_description_free (font_desc);
 }
 
 static void
@@ -839,17 +890,21 @@ run_search (GeditView        *view,
 		if (!found && wrap_around)
 		{
 			if (!search_backward)
+			{
 				found = gedit_document_search_forward (doc,
 								       NULL,
 								       NULL, /* FIXME: set the end_inter */
 								       &match_start,
 								       &match_end);
+			}
 			else
+			{
 				found = gedit_document_search_backward (doc,
 								        NULL, /* FIXME: set the start_inter */
 								        NULL, 
 								        &match_start,
 								        &match_end);
+			}
 		}
 	}
 	else
@@ -867,13 +922,10 @@ run_search (GeditView        *view,
 		gtk_text_buffer_move_mark_by_name (GTK_TEXT_BUFFER (doc),
 					"selection_bound", &match_end);
 	}
-	else
+	else if (typing)
 	{
-		if (typing)
-		{
-			gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc),
-						      &view->priv->start_search_iter);
-		}
+		gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc),
+					      &view->priv->start_search_iter);
 	}
 						      
 	if (found || (*entry_text == '\0'))
@@ -900,21 +952,27 @@ send_focus_change (GtkWidget *widget,
 	GdkEvent *fevent = gdk_event_new (GDK_FOCUS_CHANGE);
 
 	g_object_ref (widget);
-   
+#if !GTK_CHECK_VERSION (2, 21, 0)
 	if (in)
 		GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
 	else
 		GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_FOCUS);
+#endif
 
 	fevent->focus_change.type = GDK_FOCUS_CHANGE;
-	fevent->focus_change.window = g_object_ref (widget->window);
+	fevent->focus_change.window = g_object_ref (gtk_widget_get_window (widget));
 	fevent->focus_change.in = in;
-  
+
+#if !GTK_CHECK_VERSION (2, 21, 0)
 	gtk_widget_event (widget, fevent);
   
 	g_object_notify (G_OBJECT (widget), "has-focus");
 
 	g_object_unref (widget);
+#else
+	gtk_widget_send_focus_change (widget, fevent);
+#endif
+
 	gdk_event_free (fevent);
 }
 
@@ -974,7 +1032,7 @@ update_search_window_position (GeditView *view)
 {
 	gint x, y;
 	gint view_x, view_y;
-	GdkWindow *view_window = GTK_WIDGET (view)->window;
+	GdkWindow *view_window = gtk_widget_get_window (GTK_WIDGET (view));
 
 	gtk_widget_realize (view->priv->search_window);
 
@@ -1293,7 +1351,8 @@ search_entry_insert_text (GtkEditable *editable,
 
 			c = g_utf8_get_char (p);
 
-			if (!g_unichar_isdigit (c)) {
+			if (!g_unichar_isdigit (c))
+			{
 				g_signal_stop_emission_by_name (editable, "insert_text");
 				gtk_widget_error_bell (view->priv->search_entry);
 				break;
@@ -1433,13 +1492,17 @@ ensure_search_window (GeditView *view)
 
 	if (view->priv->search_window != NULL)
 	{
-		if (GTK_WINDOW (toplevel)->group)
-			gtk_window_group_add_window (GTK_WINDOW (toplevel)->group,
+		if (gtk_window_get_group (GTK_WINDOW (toplevel)))
+		{
+			gtk_window_group_add_window (gtk_window_get_group (GTK_WINDOW (toplevel)),
 						     GTK_WINDOW (view->priv->search_window));
-		else if (GTK_WINDOW (view->priv->search_window)->group)
-	 		gtk_window_group_remove_window (GTK_WINDOW (view->priv->search_window)->group,
-					 		GTK_WINDOW (view->priv->search_window));
-					 		
+		}
+		else if (gtk_window_get_group (GTK_WINDOW (view->priv->search_window)))
+		{
+			gtk_window_group_remove_window (gtk_window_get_group (GTK_WINDOW (view->priv->search_window)),
+							GTK_WINDOW (view->priv->search_window));
+		}
+
 		customize_for_search_mode (view);
 		
 		return;
@@ -1447,9 +1510,11 @@ ensure_search_window (GeditView *view)
    
 	view->priv->search_window = gtk_window_new (GTK_WINDOW_POPUP);
 
-	if (GTK_WINDOW (toplevel)->group)
-		gtk_window_group_add_window (GTK_WINDOW (toplevel)->group,
+	if (gtk_window_get_group (GTK_WINDOW (toplevel)))
+	{
+		gtk_window_group_add_window (gtk_window_get_group (GTK_WINDOW (toplevel)),
 					     GTK_WINDOW (view->priv->search_window));
+	}
 					     
 	gtk_window_set_modal (GTK_WINDOW (view->priv->search_window), TRUE);
 	
@@ -1728,11 +1793,15 @@ search_init (GtkWidget *entry,
 			gedit_view_scroll_to_cursor (view);
 
 			if (!moved || !moved_offset)
+			{
 				set_entry_background (view->priv->search_entry,
 						      GEDIT_SEARCH_ENTRY_NOT_FOUND);
+			}
 			else
+			{
 				set_entry_background (view->priv->search_entry,
 						      GEDIT_SEARCH_ENTRY_NORMAL);
+			}
 		}
 	}
 }
@@ -1743,20 +1812,26 @@ start_interactive_search_real (GeditView *view)
 	GtkTextBuffer *buffer;
 	
 	if ((view->priv->search_window != NULL) &&
-	    GTK_WIDGET_VISIBLE (view->priv->search_window))
+	    gtk_widget_get_visible (view->priv->search_window))
+	{
 		return TRUE;
+	}
 
-	if (!GTK_WIDGET_HAS_FOCUS (view))
+	if (!gtk_widget_has_focus (GTK_WIDGET (view)))
 		return FALSE;
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 
 	if (view->priv->search_mode == SEARCH)
+	{
 		gtk_text_buffer_get_selection_bounds (buffer, &view->priv->start_search_iter, NULL);
+	}
 	else
+	{
 		gtk_text_buffer_get_iter_at_mark (buffer,
 						  &view->priv->start_search_iter,
 						  gtk_text_buffer_get_insert (buffer));
+	}
 
 	ensure_search_window (view);
 
@@ -1915,7 +1990,12 @@ gedit_view_drag_data_received (GtkWidget        *widget,
 	}
 	else
 	{
-		GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_data_received (widget, context, x, y, selection_data, info, timestamp);
+		GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_data_received (widget,
+										context,
+										x, y,
+										selection_data,
+										info,
+										timestamp);
 	}
 }
 
@@ -1940,23 +2020,15 @@ gedit_view_drag_drop (GtkWidget      *widget,
 	else
 	{
 		/* Chain up */
-		result = GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_drop (widget, context, x, y, timestamp);
+		result = GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_drop (widget,
+										context,
+										x, y,
+										timestamp);
 	}
 
 	return result;
 }
 
-static void
-show_line_numbers_toggled (GtkMenu   *menu,
-			   GeditView *view)
-{
-	gboolean show;
-
-	show = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menu));
-
-	gedit_prefs_manager_set_display_line_numbers (show);
-}
-
 static GtkWidget *
 create_line_numbers_menu (GtkWidget *view)
 {
@@ -1968,8 +2040,13 @@ create_line_numbers_menu (GtkWidget *view)
 	item = gtk_check_menu_item_new_with_mnemonic (_("_Display line numbers"));
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
 					gtk_source_view_get_show_line_numbers (GTK_SOURCE_VIEW (view)));
-	g_signal_connect (item, "toggled",
-			  G_CALLBACK (show_line_numbers_toggled), view);
+
+	g_settings_bind (GEDIT_VIEW (view)->priv->editor_settings,
+			 "active",
+			 item,
+			 GEDIT_SETTINGS_DISPLAY_LINE_NUMBERS,
+			 G_SETTINGS_BIND_SET);
+	
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	
 	gtk_widget_show_all (menu);
@@ -2062,17 +2139,6 @@ search_highlight_updated_cb (GeditDocument *doc,
 	}
 }
 
-/* There is no "official" way to reset the im context in GtkTextView */
-static void
-reset_im_context (GtkTextView *text_view)
-{
-	if (text_view->need_im_reset)
-	{
-		text_view->need_im_reset = FALSE;
-		gtk_im_context_reset (text_view->im_context);
-	}
-}
-
 static void
 delete_line (GtkTextView *text_view,
 	     gint         count)
@@ -2083,7 +2149,7 @@ delete_line (GtkTextView *text_view,
 
 	buffer = gtk_text_view_get_buffer (text_view);
 
-	reset_im_context (text_view);
+	gtk_text_view_reset_im_context (text_view);
 
 	/* If there is a selection delete the selected lines and
 	 * ignore count */
@@ -2097,8 +2163,10 @@ delete_line (GtkTextView *text_view,
 			 * is at the beginning of the line */
 			count = 0;
 		}
-		else	
+		else
+		{
 			count = 1;
+		}
 	}
 	
 	gtk_text_iter_set_line_offset (&start, 0);
@@ -2132,7 +2200,9 @@ delete_line (GtkTextView *text_view,
 				gtk_text_iter_forward_to_line_end (&start);
 		}
 		else
+		{
 			gtk_text_iter_forward_line (&end);
+		}
 	}
 
 	if (!gtk_text_iter_equal (&start, &end))
@@ -2179,3 +2249,5 @@ gedit_view_delete_from_cursor (GtkTextView   *text_view,
 			break;
 	}
 }
+
+/* ex:ts=8:noet: */
